@@ -92,6 +92,30 @@ c          to assure yi(n) = 1.
       yi(n) = 1.
       call kcsplCoef(yi, x, n, coef2, nc)
       end
+
+
+      subroutine ksampAF0_b(x, y, n, coef, nc)
+      implicit none
+c              this is only for getting interplation
+      integer n  !  input number of data points
+      real*8 x(n), y(n) ! input data points (x,y)
+c                          zero is assumed at x<x(1) or x>x(n)
+      integer nc  ! input. must be >=n-1
+      real*8 coef(nc, 3) ! output. to keep the spline coefficents
+
+
+      real*8 dx, a, b
+      integer i
+      real*8 x1, x2
+ 
+      if( nc .lt. n-1 ) then
+         write(0,*) ' nc< n-1 in ksamplAF0'
+         stop 1234
+      endif
+
+      call kcsplCoef(x, y, n, coef, nc)
+      end
+
       subroutine ksampAF(x, yi, n, coef2, nc, xs)
       implicit none
       integer n
