@@ -7,8 +7,11 @@ c  ***********************************************************
          subroutine copenf(io, fnin, icon)
 c           io: integer. input.  Fortran logical device number
 c           fnin: character(*). input. Disk file name to be openend.
-c                     All %, #, #1, #2 and @ treated as follows:
-c                  
+c                     All %, #, #1, #2, @  $  treated as follows:
+c                     $(XXX) type.  XXX is regarded as enevrionmental
+c                       variable and replaced actual valu
+c                     $XXX/ or $XXX   type.  same as above
+c
 c                     @ is replaced by the hostname if PercentEnv is ' '
 c                          If hostname contianes domainname, only hostname
 c                          is extracted.   
@@ -128,10 +131,6 @@ c        *******************
  10      continue
 
          call cgetfname(fnin, fn)
-c///////
-c         write(0,*) ' fin=',fnin
-c         write(0,*) ' fot=',fn
-c/////////
 c                  see if already opened.
              inquire(file=fn(1:klena(fn)), opened=opn, exist=ex)
              if(opn) then
@@ -274,6 +273,12 @@ c          skip to the end of previous write
       fn = ' '
       fn = fnin
 
+      j = index( fn, '$')
+      do while ( j > 0 ) 
+         call creplst( fn, j, '$')
+         j = index( fn, '$')
+      enddo
+
       j = index (fn, '%') 
       do while ( j .gt. 0 )
          call creplst( fn, j,  '%')
@@ -302,7 +307,6 @@ c          skip to the end of previous write
          call creplst( fn, j, '@')
          j = index (fn, '@') 
       enddo   
-
       end
       subroutine creplst( fn, j, ch )
       implicit none
@@ -310,16 +314,58 @@ c          skip to the end of previous write
 
       character*(*) fn   ! input.  must be < 256
                          ! output
-      integer       j    ! input.  j-th chr pos. has %, # or @ 
+      integer       j    ! input.  j-th chr pos. has %, # or @  $ 
       integer       jj
-      character*1   ch   ! input. one of %, #, @. R, r
+      character*1   ch   ! input. one of %, #, @. R, r  or $
 
       integer  klena, leng, kgetpid, dummy, kgetenv2, kgetnow
  
       character*64 replst   ! to contain hostname, etc to replace %, # of or @
       integer ir(2)
+      character*16 envname
+      integer jp
 
       jj = 1
+      if( ch  == '$' ) then
+         if( fn(j+1:j+1) == '(' ) then
+c                 $(USER) style
+            jp =index( fn(j+1:), ')') 
+            if( jp > 0 ) then
+               jj = jp + j -1 
+               envname = fn(j+2:jj)
+               leng = kgetenv2(envname, replst)
+               if(leng == 0 ) then
+                  write(0,*) ' envrironmetal variable =', envname
+                  write(0,*) ' not found for fn=',trim(fn)
+                  stop
+               endif
+               jj = jj + 1
+            else
+               write(0,*) ' $( is used in file name  fn=',fn
+               write(0,*) ' but  no counterpart ) '
+               stop
+            endif
+         else
+c            $USER/  type or $USER only
+            jp =index( fn(j+1:), '/') 
+            if( jp > 0 ) then
+               jj = jp + j-1 
+c             1       jj           
+c             /tmp/$USER/ 
+               envname = fn(j+1:jj)
+            else
+               envname = trim(fn(j+1:))
+c                  USER
+               jj = len(trim(fn(j+1:)))+j
+            endif
+            leng = kgetenv2(envname, replst)
+            if(leng == 0 ) then
+               write(0,*) ' Env. =', envname, ' not exist'
+               stop
+            endif
+         endif
+      endif
+
       if( ch  .eq. '@'  ) then
          if(AtEnv .ne. ' ' ) then
             leng = kgetenv2(AtEnv, replst)
@@ -384,7 +430,7 @@ c          skip to the end of previous write
          fn = replst(1:leng)//fn(j+jj:klena(fn))
       else
          fn =
-     *   fn(1:j-1)//replst(1:leng)//fn(j+jj:klena(fn))
+     *        fn(1:j-1)//replst(1:leng)//fn(jj+j:)
       endif
 
       end
