@@ -55,8 +55,9 @@ c
       real*8  ztrunc, rmg, rmgmax
       real*8  clen2thick, erg
       integer jcut
+      integer ka
 
-
+      ka =  TrackBefMove.p.code
       erg = TrackBefMove.p.fm.p(4) - TrackBefMove.p.mass 
       if( erg .le. 0.) then
          leng = 0.
@@ -84,22 +85,21 @@ c             1 kg/m2 = 1000g/10^4 cm2 = 0.1g/cm2
      *         max( min(TrackBefMove.pos.depth/10., ztrunc), 
      *              30.d0 )
             endif
-            if( ztrunc .gt. maxstep(TrackBefMove.where) ) then
-               ztrunc =  maxstep(TrackBefMove.where)
+
+            if(ka .eq. kmuon .or. ka .eq. kpion .or. 
+     *         ka .eq. kkaon ) then
+c                    energy loss < erg's 1%-->5*erg g/cm2 = 50kg /m2
+               ztrunc =min(ztrunc, 50.d0*erg)
             endif
 
+            ztrunc =   min(ztrunc, maxstep(TrackBefMove.where))
             call cthick2len(TrackBefMove,
      *          ztrunc, leng, thick, jcut)
-
             if(rmg .lt. leng) then
                thick = clen2thick(TrackBefMove.pos.height,
      *              TrackBefMove.vec.coszenith, rmg)
                leng = rmg
             endif
-cc            else
-cc               thick = AlmostVacT
-cc               leng = rmg
-cc            endif
          elseif(Reverse .eq. 1) then
             leng = rmg
             thick = 0.
