@@ -65,7 +65,7 @@ c                   muon; pair, brems, n.i
          else   
 c                hadronic  collisions
             call csampHadint(xs, mfp)
-            if(xs .ne. smallxs .and. xs .ne. largexs) then
+            if(xs >  smallxs .and. xs .ne. largexs) then
 c                 fix target
                call cfixTarget(xs)
             endif
@@ -127,7 +127,7 @@ c           n mfp xs =1
          endif
          call csetIntInf(collkgram, .false., 'munuci')
 
-         if( xs .ne. smallxs .and. xs .ne. largexs ) then
+         if( xs > smallxs .and. xs .ne. largexs ) then
 c                 fix target; used only n.i
             call cfixTarget(xs)
          endif
@@ -473,7 +473,7 @@ ccc               use proton x-section
       endif
 
 
-      if(xs .eq. smallxs) then
+      if(xs  <=  smallxs) then
          mfp = Infty
       elseif( xs .eq. largexs) then
          mfp = 0. 
