@@ -7,11 +7,14 @@ c                    we simpley use this as <Z^2/3>
        real*8 TargetZ1_3rd  !  <Z>^(1/3).  same reason
 
        integer TargetProtonNo  !  target proton number  //     //
+       real*8  TargetXs   ! inelastic xs for this target
        common /Zair/
      *  TargetMassN, TargetAtomicN, TargetZ2, TargetZ2_3rd,  
-     *  TargetZ1_3rd,
+     *  TargetZ1_3rd, TargetXs,
      *  TargetNucleonNo, TargetProtonNo
  
+	 save /Zair/
+
 
 
 
