@@ -15,6 +15,11 @@ c	(->	--------------------------------------------
 	logical  ExactThick   !2  If T, a given length is converted into thickness with best accuracy even for very 
                               !  inclined trajectory by using numerical integration.
         logical IncMuonPolari  !1  if T, consider muon polarization
+        integer HowPhotoP      !2  if 0--> no photo hadron prod.
+                               !      1--> by using sofia
+                               !      2--> old method using vector meson
+                               !      3--> below Eg<2.5GeV,  same as 1.
+                               !      4     Eg>2.5GeV   same as 2.
         logical Freec          !1  if F, the first interaction point is forced to be the injection point else
                                !   the interaction poin is randomly sampled.
 	integer OneDim	       !1  If 0, 3 dimensional simulation. if $\ge$1, one
@@ -212,6 +217,6 @@ c	 <-)	----------------------------------------------
      *  ThinSampling, TimeStructure, HowGeomag,
      *  Trace, TraceDev,  ExactThick, OneDim, Reverse,
      *  Freec,  IncMuonPolari, MagBrem, MagPair, LpmEffect,
-     *  EndLevel, EndLevel2, Eabsorb
+     *  EndLevel, EndLevel2, Eabsorb, HowPhotoP
  
         common /cZtrackpc/ Generate, Generate2, TraceDir
